==> haskell-cabal-doctest-1.0.7-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cabal-doctest
version:              1.0.7
visibility:           public
id:                   cabal-doctest-1.0.7-I9WhlHoaqXYLIBSyuNgXGg
key:                  cabal-doctest-1.0.7-I9WhlHoaqXYLIBSyuNgXGg
license:              BSD-3-Clause
copyright:            (c) 2017 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/cabal-doctest
synopsis:             A Setup.hs helper for doctests running
description:
    Currently (beginning of 2017), there isn'\''t @cabal doctest@
    command. Yet, to properly work doctest needs plenty of configuration.
    This library provides the common bits for writing custom Setup.hs
    See <https://github.com/haskell/cabal/issues/2327 Cabal/2327> for the progress
    of @cabal doctest@, i.e. whether this library is obsolete.

category:             Distribution
abi:                  17cce89c7e27d49c4f71b0701d231a07
exposed:              True
exposed-modules:      Distribution.Extra.Doctest
import-dirs:          /usr/lib/ghc-8.8.1/site-local/cabal-doctest-1.0.7
library-dirs:         /usr/lib/ghc-8.8.1/site-local/cabal-doctest-1.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/cabal-doctest-1.0.7
hs-libraries:         HScabal-doctest-1.0.7-I9WhlHoaqXYLIBSyuNgXGg
depends:
    Cabal-3.0.0.0 base-4.13.0.0 directory-1.3.3.2 filepath-1.4.2.1

haddock-interfaces:
    /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock

haddock-html:         /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-doctest-1.0.8-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cabal-doctest
version:              1.0.8
visibility:           public
id:                   cabal-doctest-1.0.8-7JsrJFxZV5m4pH377EFuNS
key:                  cabal-doctest-1.0.8-7JsrJFxZV5m4pH377EFuNS
license:              BSD-3-Clause
copyright:            (c) 2017 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/cabal-doctest
synopsis:             A Setup.hs helper for doctests running
description:
    Currently (beginning of 2017), there isn'\''t @cabal doctest@
    command. Yet, to properly work doctest needs plenty of configuration.
    This library provides the common bits for writing custom Setup.hs
    See <https://github.com/haskell/cabal/issues/2327 Cabal/2327> for the progress
    of @cabal doctest@, i.e. whether this library is obsolete.

category:             Distribution
abi:                  3bd3ce452ed18e6e5251495ccbd4edd7
exposed:              True
exposed-modules:      Distribution.Extra.Doctest
import-dirs:          /usr/lib/ghc-8.8.2/site-local/cabal-doctest-1.0.8
library-dirs:         /usr/lib/ghc-8.8.2/site-local/cabal-doctest-1.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/cabal-doctest-1.0.8
hs-libraries:         HScabal-doctest-1.0.8-7JsrJFxZV5m4pH377EFuNS
depends:
    Cabal-3.0.1.0 base-4.13.0.0 directory-1.3.4.0 filepath-1.4.2.1

haddock-interfaces:
    /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock

haddock-html:         /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
